package com.virtual.plat.server.organize;

import com.extjs.gxt.ui.client.data.BaseModelData;
import com.extjs.gxt.ui.client.data.ModelData;
import com.google.common.collect.Lists;
import com.google.common.collect.Maps;
import com.virtual.common.AppException;
import com.virtual.common.ErrorCodes;
import com.virtual.common.FuncUtil;
import com.virtual.common.StringManager;
import com.virtual.plat.client.operator.LoginInfo;
import com.virtual.plat.client.rpc.RpcPagingLoadResult;
import com.virtual.plat.client.rpc.RpcResult;
import com.virtual.plat.server.RequestData;
import com.virtual.plat.server.RequestHandler;
import com.virtual.plat.server.ServerUtils;
import com.virtual.plat.server.backuphistory.BackupHistoryMgr;
import com.virtual.plat.server.cloudbackupstrategy.CloudBackUpStrategyMgr;
import com.virtual.plat.server.clouddiskworkflow.DiskWorkflowMgr;
import com.virtual.plat.server.cluster.ClusterMgr;
import com.virtual.plat.server.common.CommonMgr;
import com.virtual.plat.server.controller.entity.DomainPo;
import com.virtual.plat.server.controller.entity.OrganizePo;
import com.virtual.plat.server.controller.entity.ResourcePoolPo;
import com.virtual.plat.server.controller.entity.VmUserPo;
import com.virtual.plat.server.controller.entity.domain.DistributeDomainData;
import com.virtual.plat.server.entity.ApplyDisk;
import com.virtual.plat.server.entity.DesktopPool;
import com.virtual.plat.server.entity.Domain;
import com.virtual.plat.server.entity.DomainCpuDetail;
import com.virtual.plat.server.entity.Host;
import com.virtual.plat.server.entity.OrgResourcePool;
import com.virtual.plat.server.entity.OrgUser;
import com.virtual.plat.server.entity.Organization;
import com.virtual.plat.server.entity.PublicCloud;
import com.virtual.plat.server.entity.QueryConfig;
import com.virtual.plat.server.entity.QueryResult;
import com.virtual.plat.server.entity.ResourcePool;
import com.virtual.plat.server.entity.RpCluster;
import com.virtual.plat.server.entity.User;
import com.virtual.plat.server.entity.UserGroup;
import com.virtual.plat.server.entity.UserVm;
import com.virtual.plat.server.entity.QueryConfig.SortDir;
import com.virtual.plat.server.host.HostMgr;
import com.virtual.plat.server.http.pool.HttpConnectionManager;
import com.virtual.plat.server.message.MessageMgr;
import com.virtual.plat.server.message.UpdateMessageTask;
import com.virtual.plat.server.operlog.OperationLogMgr;
import com.virtual.plat.server.operlog.OperationLogMgr.OperationResult;
import com.virtual.plat.server.organize.OrgParamertersHandler;
import com.virtual.plat.server.organize.OrganizationMgr;
import com.virtual.plat.server.organize.OrganizationUtils;
import com.virtual.plat.server.organize.resource.CloudResourceFactory;
import com.virtual.plat.server.publiccloud.PublicCloudHandler;
import com.virtual.plat.server.publiccloud.PublicCloudMgr;
import com.virtual.plat.server.publiccloud.PublicCloudUtils;
import com.virtual.plat.server.resourcepool.ResourcePoolMgr;
import com.virtual.plat.server.resourcepool.ResourcePoolUtils;
import com.virtual.plat.server.rs.entity.RsCommList;
import com.virtual.plat.server.rs.entity.RsRate;
import com.virtual.plat.server.rs.entity.RsTrendRate;
import com.virtual.plat.server.user.UserGroupMgr;
import com.virtual.plat.server.user.UserMgr;
import com.virtual.plat.server.virtualdesktoppool.VirDesktopPoolMgr;
import com.virtual.plat.server.virtualhost.DomainCpuDetailMgr;
import com.virtual.plat.server.virtualhost.DomainHandler;
import com.virtual.plat.server.virtualhost.DomainMgr;
import com.virtual.plat.server.virtualhost.DomainUtils;
import com.virtual.plat.server.vm.vmware.VMwareConnection;
import com.virtual.plat.server.vm.vmware.VMwareConnectionManager;
import com.vmware.vim25.mo.VirtualMachine;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Date;
import java.util.HashMap;
import java.util.Iterator;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.Timer;
import java.util.Map.Entry;
import javax.annotation.Resource;
import javax.servlet.http.HttpSession;
import org.apache.commons.collections.CollectionUtils;
import org.apache.commons.lang.StringUtils;
import org.apache.commons.lang.time.DateFormatUtils;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;
import org.apache.http.HttpResponse;
import org.apache.http.client.methods.HttpGet;
import org.apache.http.impl.client.DefaultHttpClient;
import org.apache.http.util.EntityUtils;
import org.springframework.stereotype.Service;

@Service("orgHandler")
public class OrganizationHandler {

   public static final int PERIOD = 1000;
   protected Log log = LogFactory.getLog(this.getClass());
   private StringManager sm = StringManager.getManager(OrganizationHandler.class);
   private StringManager strMng = StringManager.getManager(DomainHandler.class);
   @Resource
   private OrganizationMgr organizationMgr = null;
   @Resource
   private PublicCloudMgr publicCloudMgr = null;
   @Resource
   private VMwareConnectionManager vmwareConnManager = null;
   @Resource
   private CommonMgr commonMgr = null;
   @Resource
   private OperationLogMgr operationLogMgr = null;
   @Resource
   private MessageMgr messageMgr = null;
   @Resource
   private HttpConnectionManager httpConnManager = null;
   @Resource
   private PublicCloudHandler publicCloudHandler = null;
   @Resource
   private DomainHandler domainHandler = null;
   @Resource
   private VirDesktopPoolMgr virDesktopPoolMgr = null;
   @Resource
   private DiskWorkflowMgr diskWorkflowMgr = null;
   @Resource
   private HostMgr hostMgr = null;
   @Resource
   private UserMgr userMgr = null;
   @Resource
   private DomainCpuDetailMgr domainCpuDetailMgr = null;
   @Resource
   private CloudResourceFactory cloudResourceFactory = null;
   @Resource
   private DomainMgr domainMgr = null;
   @Resource
   private ResourcePoolMgr resourcePoolMgr = null;
   @Resource
   private ClusterMgr clusterMgr = null;
   @Resource
   private UserGroupMgr userGroupMgr = null;
   @Resource
   private OrgParamertersHandler orgParamertersHandler;
   @Resource
   private CloudBackUpStrategyMgr cloudBackUpStrategyMgr;
   @Resource
   private BackupHistoryMgr backupHistoryMgr = null;
   @Resource
   private RequestHandler requestMgr = null;


   public List queryHomePageVmByOrgId(Long var1) {
      ArrayList var2 = new ArrayList();
      if(var1 == null) {
         return var2;
      } else {
         ArrayList var3 = new ArrayList();
         StringBuilder var4;
         (var4 = new StringBuilder()).append(" SELECT DISTINCT vm.ID, vm.DOMAIN_NAME, vm.TITLE, vm.STATUS,vm.MEMORY,vm.CPU,vm.STORAGE_CAPACITY FROM TBL_DOMAIN vm  LEFT JOIN  TBL_USER_VM user ON user.DOMAIN_ID = vm.ID WHERE user.ORG_ID = ");
         var4.append(var1);
         StringBuilder var5;
         (var5 = new StringBuilder()).append("SELECT DISTINCT user.DOMAIN_ID, TITLE FROM TBL_USER_VM user WHERE user.ORG_ID =");
         var5.append(var1);
         List var7;
         if((var7 = this.commonMgr.queryBySql(var4.toString())) != null && var7.size() > 0) {
            Iterator var8 = var7.iterator();

            while(var8.hasNext()) {
               Object[] var10 = (Object[])var8.next();
               Domain var6 = new Domain();
               var3.add(FuncUtil.getLongValue(var10[0]));
               var6.setStatus((String)var10[3]);
               var6.setMemory(FuncUtil.getLongValue(var10[4]));
               var6.setCpu(FuncUtil.getIntegerValue(var10[5]));
               var6.setStorageCapacity(FuncUtil.getLongValue(var10[6]));
               var2.add(var6);
            }
         }

         if((var7 = this.commonMgr.queryBySql(var5.toString())) != null && var7.size() > 0) {
            Iterator var11 = var7.iterator();

            while(var11.hasNext()) {
               var1 = FuncUtil.getLongValue(((Object[])var11.next())[0]);
               if(!var3.contains(var1)) {
                  Domain var9;
                  (var9 = new Domain()).setStatus("unknown");
                  var9.setMemory(Long.valueOf(0L));
                  var9.setCpu(Integer.valueOf(0));
                  var9.setStorageCapacity(Long.valueOf(0L));
                  var2.add(var9);
               }
            }
         }

         return var2;
      }
   }

   private Map a(Set var1) {
      ArrayList var4 = Lists.newArrayList(var1);
      QueryConfig var2;
      (var2 = new QueryConfig()).addRestriction("domainIds", var4);
      QueryResult var5 = this.organizationMgr.queryUserVmByCondition(var2);
      HashMap var7 = Maps.newHashMap();
      if(CollectionUtils.isEmpty(var5.getData())) {
         return var7;
      } else {
         Iterator var6 = var5.getData().iterator();

         while(var6.hasNext()) {
            UserVm var3 = (UserVm)var6.next();
            var7.put(var3.getDomainId(), var3);
         }

         return var7;
      }
   }

   public RpcPagingLoadResult queryVmByCondition(QueryConfig var1) {
      ArrayList var2 = Lists.newArrayList();

      try {
         HashMap var3 = Maps.newHashMap();
         HashMap var17 = var3;
         ArrayList var16 = var2;
         QueryConfig var9 = var1;
         OrganizationHandler var8 = this;
         QueryResult var10;
         long var10000;
         if(CollectionUtils.isEmpty((var10 = this.organizationMgr.queryVmIdMapInOrg(var1)).getData())) {
            var10000 = 0L;
         } else {
            Long var11 = (Long)var1.getRestriction("orgId");
            Long var31 = (Long)var1.getRestriction("desktopPoolId");
            Map var32 = this.a(var31, var11);
            Iterator var22 = var10.getData().iterator();

            while(var22.hasNext()) {
               Object[] var23 = (Object[])var22.next();
               HashMap var5 = Maps.newHashMap();
               long var25 = Long.parseLong(var23[0].toString());
               var5.put("id", Long.valueOf(var25));
               var5.put("title", var23[5]);
               if(var9.getRestriction("desktopPoolId") != null || var9.getRestriction("userId") != null || var9.getRestriction("userGrpId") != null) {
                  if(var23[17] != null) {
                     var5.put("expireDate", DateFormatUtils.format((Date)var23[17], "yyyy-MM-dd HH:mm:ss"));
                  }

                  DesktopPool var27;
                  if(var23[16] != null && (var27 = (DesktopPool)var32.get(var23[16])) != null) {
                     var5.put("assignMode", var27.getAssignMode());
                  }
               }

               if(var23[2] == null) {
                  var5.put("status", "unknown");
                  var5.put("cpuRate", Double.valueOf(0.0D));
                  var5.put("memRate", Double.valueOf(0.0D));
                  var5.put("cpu", Integer.valueOf(0));
                  var5.put("mem", Long.valueOf(0L));
                  var5.put("storage", Long.valueOf(0L));
                  var5.put("cloudType", var23[15]);
                  var16.add(var5);
               } else {
                  long var45 = Long.parseLong(var23[2].toString());
                  String var6 = var23[1].toString();
                  var5.put("id", Long.valueOf(var25));
                  var5.put("uniqueKey", var6);
                  var5.put("vmKey", var6);
                  var5.put("cloudId", Long.valueOf(var45));
                  var5.put("vCenterId", Long.valueOf(var45));
                  var5.put("resId", var23[3]);
                  var5.put("resName", var23[4]);
                  var5.put("title", var23[5]);
                  var5.put("desc", var23[6]);
                  var5.put("hostId", var23[7]);
                  var5.put("clusterId", var23[8]);
                  var5.put("status", var23[9]);
                  var5.put("system", var23[10]);
                  var5.put("antivirusConfig", var23[11]);
                  var5.put("name", var23[12]);
                  var5.put("cpu", var23[13]);
                  var5.put("mem", var23[14]);
                  var5.put("cloudType", var23[15]);
                  Host var7 = var8.hostMgr.queryHostByIdWithoutException(FuncUtil.getLongValue(var23[7]).longValue());
                  var5.put("host", var7.getName());
                  var5.put("hostKey", var7.getUniqueKey());
                  var16.add(var5);
                  if(var17.containsKey(Long.valueOf(var45))) {
                     ((List)var17.get(Long.valueOf(var45))).add(var6);
                  } else {
                     ArrayList var34;
                     (var34 = Lists.newArrayList()).add(var6);
                     var17.put(Long.valueOf(var45), var34);
                  }
               }
            }

            var10000 = var10.getTotalLength();
         }

         long var33 = var10000;
         HashMap var35 = Maps.newHashMap();
         Iterator var30 = var3.entrySet().iterator();

         Map var41;
         while(var30.hasNext()) {
            Entry var36 = (Entry)var30.next();
            Collection var10001 = (Collection)var36.getValue();
            long var44 = ((Long)var36.getKey()).longValue();
            Collection var40 = var10001;
            PublicCloud var43 = this.publicCloudMgr.queryPublicCloudById(Long.valueOf(var44));
            var41 = this.cloudResourceFactory.getCloudResource(var43).queryVmInfo(var40);
            var35.put(var36.getKey(), var41);
         }

         var30 = var2.iterator();

         while(var30.hasNext()) {
            Map var37;
            if((var37 = (Map)var30.next()).get("cloudId") != null && var37.get("uniqueKey") != null && var37.get("status") != null && !"unknown".equals(var37.get("status").toString()) && !"shutOff".equals(var37.get("status").toString())) {
               long var42 = Long.parseLong(var37.get("cloudId").toString());
               String var38 = var37.get("uniqueKey").toString();
               if((var41 = (Map)var35.get(Long.valueOf(var42))) == null) {
                  var37.put("cpuRate", Double.valueOf(0.0D));
                  var37.put("memRate", Double.valueOf(0.0D));
               } else {
                  Map var39;
                  if((var39 = (Map)var41.get(var38)) == null) {
                     var37.put("cpuRate", Double.valueOf(0.0D));
                     var37.put("memRate", Double.valueOf(0.0D));
                  } else {
                     var37.put("cpuRate", var39.get("cpuRate"));
                     var37.put("memRate", var39.get("memRate"));
                     var37.put("protectModel", var39.get("protectModel"));
                  }
               }
            } else {
               var37.put("cpuRate", Double.valueOf(0.0D));
               var37.put("memRate", Double.valueOf(0.0D));
            }
         }

         return new RpcPagingLoadResult(var2, (long)var1.getOffset(), var33);
      } catch (AppException var29) {
         this.log.error(var29);
         RpcPagingLoadResult var4;
         (var4 = new RpcPagingLoadResult(var29.getErrorCode(), var29.getErrorMessage())).setData(var2);
         return var4;
      }
   }

   private long a(QueryConfig var1, List var2, Map var3) {
      QueryResult var4;
      if(CollectionUtils.isEmpty((var4 = this.organizationMgr.queryVmIdMapInOrg(var1)).getData())) {
         return 0L;
      } else {
         Long var5 = (Long)var1.getRestriction("orgId");
         Long var6 = (Long)var1.getRestriction("desktopPoolId");
         Map var15 = this.a(var6, var5);
         Iterator var8 = var4.getData().iterator();

         while(var8.hasNext()) {
            Object[] var9 = (Object[])var8.next();
            HashMap var16 = Maps.newHashMap();
            long var11 = Long.parseLong(var9[0].toString());
            var16.put("id", Long.valueOf(var11));
            var16.put("title", var9[5]);
            if(var1.getRestriction("desktopPoolId") != null || var1.getRestriction("userId") != null || var1.getRestriction("userGrpId") != null) {
               if(var9[17] != null) {
                  var16.put("expireDate", DateFormatUtils.format((Date)var9[17], "yyyy-MM-dd HH:mm:ss"));
               }

               DesktopPool var13;
               if(var9[16] != null && (var13 = (DesktopPool)var15.get(var9[16])) != null) {
                  var16.put("assignMode", var13.getAssignMode());
               }
            }

            if(var9[2] == null) {
               var16.put("status", "unknown");
               var16.put("cpuRate", Double.valueOf(0.0D));
               var16.put("memRate", Double.valueOf(0.0D));
               var16.put("cpu", Integer.valueOf(0));
               var16.put("mem", Long.valueOf(0L));
               var16.put("storage", Long.valueOf(0L));
               var16.put("cloudType", var9[15]);
               var2.add(var16);
            } else {
               long var19 = Long.parseLong(var9[2].toString());
               String var7 = var9[1].toString();
               var16.put("id", Long.valueOf(var11));
               var16.put("uniqueKey", var7);
               var16.put("vmKey", var7);
               var16.put("cloudId", Long.valueOf(var19));
               var16.put("vCenterId", Long.valueOf(var19));
               var16.put("resId", var9[3]);
               var16.put("resName", var9[4]);
               var16.put("title", var9[5]);
               var16.put("desc", var9[6]);
               var16.put("hostId", var9[7]);
               var16.put("clusterId", var9[8]);
               var16.put("status", var9[9]);
               var16.put("system", var9[10]);
               var16.put("antivirusConfig", var9[11]);
               var16.put("name", var9[12]);
               var16.put("cpu", var9[13]);
               var16.put("mem", var9[14]);
               var16.put("cloudType", var9[15]);
               Host var18 = this.hostMgr.queryHostByIdWithoutException(FuncUtil.getLongValue(var9[7]).longValue());
               var16.put("host", var18.getName());
               var16.put("hostKey", var18.getUniqueKey());
               var2.add(var16);
               if(var3.containsKey(Long.valueOf(var19))) {
                  ((List)var3.get(Long.valueOf(var19))).add(var7);
               } else {
                  ArrayList var17;
                  (var17 = Lists.newArrayList()).add(var7);
                  var3.put(Long.valueOf(var19), var17);
               }
            }
         }

         return var4.getTotalLength();
      }
   }

   private Map a(Long var1, Long var2) {
      HashMap var3 = Maps.newHashMap();
      if(var2 == null && var1 == null) {
         return var3;
      } else if(var1 != null) {
         try {
            DesktopPool var8 = this.virDesktopPoolMgr.queryDesktopPoolById(var1);
            var3.put(var8.getId(), var8);
         } catch (Exception var4) {
            this.log.error((Object)null, var4);
         }

         return var3;
      } else {
         QueryConfig var5;
         (var5 = new QueryConfig()).addRestriction("orgId", var2);
         QueryResult var6;
         if(CollectionUtils.isEmpty((var6 = this.virDesktopPoolMgr.queryVirDesktopPoolList(var5)).getData())) {
            return var3;
         } else {
            Iterator var7 = var6.getData().iterator();

            while(var7.hasNext()) {
               DesktopPool var9 = (DesktopPool)var7.next();
               var3.put(var9.getId(), var9);
            }

            return var3;
         }
      }
   }

   private Map a(Collection var1, long var2) {
      PublicCloud var4 = this.publicCloudMgr.queryPublicCloudById(Long.valueOf(var2));
      return this.cloudResourceFactory.getCloudResource(var4).queryVmInfo(var1);
   }

   public List queryVirtHostThrend(Long var1, PublicCloud var2, String var3, Integer var4) {
      if(var1 != null && var2 != null) {
         Object var5 = new ArrayList();
         VMwareConnection var6 = null;

         try {
            String var7 = "SELECT DISTINCT ORG_ID,DOMAIN_ID FROM TBL_USER_VM WHERE ORG_ID=" + var1 + " AND PUBLIC_CLOUD_ID = " + var2.getId();
            List var22;
            if((var22 = this.organizationMgr.queryInfoBySql(var7)) != null && var22.size() > 0) {
               if(var2 != null && var2.getFlag().intValue() == 3) {
                  var6 = this.vmwareConnManager.getConnection(var2.getConnectUri(), var2.getUserName(), var2.getPassword());
                  QueryConfig var25 = new QueryConfig();
                  Long var26 = Long.valueOf(System.currentTimeMillis() / 1000L);
                  int var28 = var4 == null?20:var4.intValue();
                  Long var18 = Long.valueOf(var26.longValue() - (long)(var28 * 60));
                  var25.addRestriction("nowTime", var26);
                  var25.addRestriction("preTime", var18);
                  var25.addRestriction("type", var3);
                  var25.addRestriction("orgId_in", var1);
                  var25.setSortInfo(SortDir.Asc, "time");
                  var25.setLimit(5);
                  Iterator var15 = this.domainCpuDetailMgr.queryAvgTopnByCondition(var25).iterator();

                  while(var15.hasNext()) {
                     Long var16 = FuncUtil.getLongValue(((Object[])var15.next())[0]);
                     var25.addRestriction("uuid", var16);
                     List var20;
                     if((var20 = this.domainCpuDetailMgr.queryByCondition(var25).getData()) != null && var20.size() != 0) {
                        RsTrendRate var27 = new RsTrendRate();
                        var3 = "vm-" + var16;
                        VirtualMachine var17 = var6.queryVMByKey(var3);
                        var27.setName(var17.getName());
                        ArrayList var19 = new ArrayList();
                        Iterator var21 = var20.iterator();

                        while(var21.hasNext()) {
                           DomainCpuDetail var29 = (DomainCpuDetail)var21.next();
                           RsRate var10;
                           (var10 = new RsRate()).setTime(Long.valueOf(var29.getTime().longValue() * 1000L));
                           var10.setRate(var29.getMemory());
                           var19.add(var10);
                        }

                        var27.setRates(var19);
                        ((List)var5).add(var27);
                     }
                  }
               } else if(var2.getFlag().intValue() == 2) {
                  ArrayList var8 = new ArrayList();
                  Iterator var23 = var22.iterator();

                  while(var23.hasNext()) {
                     Object[] var9 = (Object[])var23.next();
                     var8.add(FuncUtil.getLongValue(var9[1]));
                  }

                  BaseModelData var24;
                  (var24 = new BaseModelData()).set("type", var3);
                  var24.set("idList", var8);
                  var24.set("interval", var4);
                  var5 = OrganizationUtils.queryTopNThrend(var2, var24, this.httpConnManager, this.domainMgr);
               }
            }
         } catch (AppException var13) {
            this.log.error((Object)null, var13);
         } finally {
            if(var6 != null) {
               this.vmwareConnManager.releaseConnection(var2.getConnectUri(), var2.getUserName(), var6);
            }

         }

         return (List)var5;
      } else {
         return null;
      }
   }

   public List queryComputeResList(PublicCloud var1, String var2) {
      Object var3 = new ArrayList();
      DefaultHttpClient var4 = null;
      var2 = "/cas/casrs/cluster/computeResList?clusterIds=" + var2;
      HttpGet var11;
      (var11 = new HttpGet(var2)).addHeader("accept", "application/xml");

      try {
         HttpResponse var5 = (var4 = this.httpConnManager.getConnection(var1.getProtocal(), var1.getUri(), var1.getPort().intValue(), var1.getUserName(), var1.getPassword())).execute(var11);
         String var10;
         if(200 == var5.getStatusLine().getStatusCode() && StringUtils.isNotEmpty(var10 = EntityUtils.toString(var5.getEntity(), "UTF-8"))) {
            var3 = ((RsCommList)FuncUtil.convertXmlToObject(var10.trim(), RsCommList.class)).getData();
         }
      } catch (Exception var8) {
         this.log.error((Object)null, var8);
      } finally {
         var11.abort();
         this.httpConnManager.releaseConnection(var1.getProtocal(), var1.getUri(), var1.getPort().intValue(), var1.getUserName(), var4);
      }

      return (List)var3;
   }

   public RpcPagingLoadResult queryTempletByOrgId(QueryConfig var1, LoginInfo var2, Boolean var3) {
      Long var16 = (Long)var1.getRestriction("orgId");
      Long var4 = (Long)var1.getRestriction("resourcePoolId");
      QueryConfig var5;
      (var5 = new QueryConfig()).addRestriction("orgId", var16);
      var5.addRestriction("resourcePoolId", var4);
      ServerUtils.addOperatorGroupQueryCfg(var2, var1);

      try {
         if(var16 == null) {
            return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
         } else {
            ArrayList var15 = new ArrayList();
            ArrayList var6 = new ArrayList();
            long var28;
            if(var1.getRestriction("templeteId") == null) {
               if(var4 != null) {
                  ResourcePool var18 = this.resourcePoolMgr.queryResourcePoolById(var4);
                  var6.add(var18.getCloudId());
               } else {
                  QueryResult var19;
                  if((var19 = this.organizationMgr.queryResourcePoolByConfig(var5)).getLength() > 0) {
                     Iterator var21 = var19.getData().iterator();

                     while(var21.hasNext()) {
                        Long var7 = ((ResourcePool)var21.next()).getCloudId();
                        if(!var6.contains(var7)) {
                           var6.add(var7);
                        }
                     }
                  }
               }

               QueryConfig var20;
               (var20 = new QueryConfig()).addRestriction("cloudIds", var6);
               var20.addRestriction("enable", Integer.valueOf(2));
               var20.setPagingInfo(var1.getOffset(), var1.getLimit());
               QueryResult var24 = new QueryResult();

               try {
                  var24 = this.domainMgr.queryDomainsByCondition(var20);
               } catch (Exception var13) {
                  this.log.error("org has none resourcePool");
               }

               if(CollectionUtils.isEmpty(var24.getData())) {
                  return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
               }

               var28 = var24.getTotalLength();
               List var22 = var24.getData();

               StringBuilder var11;
               PublicCloud var25;
               Long var26;
               for(Iterator var27 = var6.iterator(); var27.hasNext(); a(var15, var22, var26, var25.getFlag(), var11)) {
                  var25 = OrganizationUtils.getPublicCloudById(var26 = (Long)var27.next(), this.publicCloudMgr);
                  QueryConfig var10;
                  (var10 = new QueryConfig()).addRestriction("cloudId", var26);
                  var10.addRestriction("orgId", var16);
                  QueryResult var29 = this.resourcePoolMgr.queryAllResourcePool(var10);
                  var11 = new StringBuilder();
                  if(var29.getLength() > 0) {
                     Iterator var30 = var29.getData().iterator();

                     while(var30.hasNext()) {
                        ResourcePool var12 = (ResourcePool)var30.next();
                        var11.append(var12.getName()).append(",");
                     }
                  }

                  if(var11.length() > 0) {
                     var11.deleteCharAt(var11.length() - 1);
                  }
               }
            } else {
               var16 = (Long)var1.getRestriction("templeteId");
               Domain var17 = this.domainMgr.queryTemplateById(var16);
               ArrayList var23;
               (var23 = new ArrayList()).add(var17);
               var28 = 1L;
               a(var15, var23, var17.getPublicCloudId(), var17.getCloudType(), (StringBuilder)null);
            }

            return var28 > 0L?new RpcPagingLoadResult(var15, (long)var1.getOffset(), var28):new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
         }
      } catch (AppException var14) {
         ServerUtils.logAppException(this.log, var14);
         RpcPagingLoadResult var8;
         (var8 = new RpcPagingLoadResult(var14.getErrorCode(), var14.getErrorMessage())).setData(new ArrayList());
         return var8;
      }
   }

   private static void a(List var0, List var1, Long var2, Integer var3, StringBuilder var4) {
      if(!CollectionUtils.isEmpty(var1)) {
         Iterator var7 = var1.iterator();

         while(var7.hasNext()) {
            Domain var5;
            if((var5 = (Domain)var7.next()).getPublicCloudId().equals(var2)) {
               BaseModelData var6;
               (var6 = new BaseModelData()).set("id", var5.getId());
               var6.set("description", var5.getDescription());
               var6.set("domainName", var5.getTitle());
               var6.set("memory", var5.getMemory());
               var6.set("cpu", var5.getCpu());
               var6.set("storage", var5.getStorageCapacity());
               var6.set("createDate", var5.getCreateDate());
               var6.set("system", var5.getSystem());
               if(var3.intValue() == 3) {
                  var6.set("vmKey", var5.getUniqueKey());
                  if(var5.getOsVersion() != null && var5.getOsVersion().contains("Windows")) {
                     var6.set("system", Integer.valueOf(0));
                  } else {
                     var6.set("system", Integer.valueOf(1));
                  }
               }

               var6.set("osVersion", var5.getOsVersion());
               var6.set("publicCloudType", var3);
               var6.set("publicCloudId", var5.getPublicCloudId());
               if(var4 != null) {
                  var6.set("resourcePoolName", var4);
               }

               var0.add(var6);
            }
         }

      }
   }

   public RpcPagingLoadResult querySsvVmByCondition(QueryConfig var1) {
      new ArrayList();
      Long var2 = (Long)var1.getRestriction("orgId");

      try {
         if(var2 == null) {
            return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
         } else {
            ArrayList var11 = new ArrayList();
            ArrayList var3 = new ArrayList();
            HashMap var6 = new HashMap();
            ArrayList var4;
            String[] var5;
            int var7;
            int var8;
            String var9;
            if(var1.getRestriction("vmId_in") != null) {
               var4 = new ArrayList();
               var7 = (var5 = ((String)var1.getRestriction("vmId_in")).split(",")).length;

               for(var8 = 0; var8 < var7; ++var8) {
                  var9 = var5[var8];
                  var4.add(Long.valueOf(var9));
               }

               var1.addRestriction("vmId_in", var4);
            } else if(var1.getRestriction("vmId_not_in") != null) {
               var4 = new ArrayList();
               var7 = (var5 = ((String)var1.getRestriction("vmId_not_in")).split(",")).length;

               for(var8 = 0; var8 < var7; ++var8) {
                  var9 = var5[var8];
                  var4.add(Long.valueOf(var9));
               }

               var1.addRestriction("vmId_not_in", var4);
            }

            QueryResult var13;
            if((var13 = this.organizationMgr.querySsvVmByCondition(var1)) != null && var13.getData() != null && var13.getData().size() > 0) {
               Iterator var16 = var13.getData().iterator();

               while(var16.hasNext()) {
                  UserVm var15 = (UserVm)var16.next();
                  if(!var6.containsKey(var15.getDomainId())) {
                     var11.add(var15.getDomainId());
                     var3.add(var15.getUniqueKey());
                     var6.put(var15.getDomainId(), var15);
                  } else {
                     ((UserVm)var6.get(var15.getDomainId())).setFlag(Integer.valueOf(3));
                  }
               }

               long var14 = var13.getTotalLength();
               if(var1.getRestriction("total") != null) {
                  return new RpcPagingLoadResult(new ArrayList(), (long)var1.getOffset(), var14);
               } else {
                  QueryConfig var17 = new QueryConfig(var1.getSortDir(), var1.getSortField());
                  if(var1.getRestriction("network") != null) {
                     var17.addRestriction("network", Boolean.valueOf(true));
                  }

                  List var12 = this.queryVmInfo(var11, var6, var17);
                  return new RpcPagingLoadResult(var12, (long)var1.getOffset(), var14);
               }
            } else {
               return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
            }
         }
      } catch (AppException var10) {
         ServerUtils.logAppException(this.log, var10);
         return new RpcPagingLoadResult(var10.getErrorCode(), var10.getErrorMessage());
      }
   }

   public RpcPagingLoadResult querySsvVmCount(QueryConfig var1) {
      new ArrayList();
      Long var2 = (Long)var1.getRestriction("orgId");

      try {
         if(var2 == null) {
            return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
         } else if(!ResourcePoolUtils.isResoucePoolUsedByOrg(var2, this.resourcePoolMgr)) {
            return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
         } else {
            StringBuffer var11 = new StringBuffer();
            ArrayList var3 = new ArrayList();
            HashMap var4 = new HashMap();
            ArrayList var5;
            int var6;
            String[] var7;
            int var8;
            String var9;
            if(var1.getRestriction("vmId_in") != null) {
               var5 = new ArrayList();
               var6 = (var7 = ((String)var1.getRestriction("vmId_in")).split(",")).length;

               for(var8 = 0; var8 < var6; ++var8) {
                  var9 = var7[var8];
                  var5.add(Long.valueOf(var9));
               }

               var1.addRestriction("vmId_in", var5);
            } else if(var1.getRestriction("vmId_not_in") != null) {
               var5 = new ArrayList();
               var6 = (var7 = ((String)var1.getRestriction("vmId_not_in")).split(",")).length;

               for(var8 = 0; var8 < var6; ++var8) {
                  var9 = var7[var8];
                  var5.add(Long.valueOf(var9));
               }

               var1.addRestriction("vmId_not_in", var5);
            }

            QueryResult var13;
            if((var13 = this.organizationMgr.querySsvVmByCondition(var1)) != null && var13.getData() != null && var13.getData().size() > 0) {
               Iterator var15 = var13.getData().iterator();

               while(var15.hasNext()) {
                  UserVm var16 = (UserVm)var15.next();
                  if(!var4.containsKey(var16.getDomainId())) {
                     var3.add(var16.getDomainId());
                     var11.append(var16.getDomainId()).append(",");
                     var4.put(var16.getDomainId(), var16);
                  } else {
                     ((UserVm)var4.get(var16.getDomainId())).setFlag(Integer.valueOf(3));
                  }
               }

               if(var11.length() > 0) {
                  var11.deleteCharAt(var11.length() - 1);
               }

               long var14 = var13.getTotalLength();
               List var12 = this.a((List)var3);
               return new RpcPagingLoadResult(var12, (long)var1.getOffset(), var14);
            } else {
               return new RpcPagingLoadResult(new ArrayList(), 0L, 0L);
            }
         }
      } catch (AppException var10) {
         ServerUtils.logAppException(this.log, var10);
         return new RpcPagingLoadResult(var10.getErrorCode(), var10.getErrorMessage());
      }
   }

   public ModelData queryVmStatusByVirtualDesktop(DesktopPool var1) {
      BaseModelData var2 = new BaseModelData();
      int var3 = 0;
      int var5 = 0;
      if(var1 != null && var1.getId() != null) {
         Long var4;
         if((var4 = var1.getOrgId()) != null) {
            QueryConfig var6;
            (var6 = new QueryConfig()).addRestriction("orgId", var4);
            QueryResult var12;
            if((var12 = this.resourcePoolMgr.queryAllResourcePool(var6)) == null || var12.getData() == null || var12.getData().isEmpty()) {
               throw new AppException(1527);
            }

            QueryConfig var13;
            (var13 = new QueryConfig()).addRestriction("desktopPoolId", var1.getId());
            if((var12 = this.organizationMgr.queryUserVmByCondition(var13)) != null && var12.getData() != null && var12.getData().size() > 0) {
               ArrayList var15 = new ArrayList();
               ArrayList var7 = new ArrayList();
               Iterator var8 = var12.getData().iterator();

               while(var8.hasNext()) {
                  UserVm var9 = (UserVm)var8.next();
                  if(!var7.contains(var9.getDomainId())) {
                     var7.add(var9.getDomainId());
                     var15.add(var9);
                  }
               }

               try {
                  int var14 = var15.size();
                  QueryConfig var17;
                  (var17 = new QueryConfig()).addRestriction("desktopPoolId", var1.getId());
                  Iterator var11 = this.organizationMgr.queryVMStatus(var17).iterator();

                  while(var11.hasNext()) {
                     String var16;
                     if((var16 = (String)var11.next()) != null) {
                        if(!"running".equals(var16) && !"paused".equals(var16)) {
                           if("shutOff".equals(var16)) {
                              ++var5;
                           }
                        } else {
                           ++var3;
                        }
                     }
                  }

                  (var2 = new BaseModelData()).set("total", Integer.valueOf(var14));
                  var2.set("run", Integer.valueOf(var3));
                  var2.set("shutoff", Integer.valueOf(var5));
               } catch (Exception var10) {
                  this.log.error((Object)null, var10);
               }
            }
         }

         return var2;
      } else {
         throw new AppException(14000);
      }
   }

   private List a(List var1) {
      ArrayList var2 = new ArrayList();
      QueryConfig var3;
      (var3 = new QueryConfig()).addRestriction("idList", var1);
      QueryResult var5;
      if(!CollectionUtils.isEmpty((var5 = this.domainMgr.queryDomainsByCondition(var3)).getData())) {
         Iterator var6 = var5.getData().iterator();

         while(var6.hasNext()) {
            String var7 = ((Domain)var6.next()).getStatus();
            BaseModelData var4;
            (var4 = new BaseModelData()).set("status", var7);
            var2.add(var4);
         }
      }

      return var2;
   }

   public List queryVmInfo(List var1, Map var2, QueryConfig var3) {
      QueryConfig var4;
      (var4 = new QueryConfig()).addRestriction("idList", var1);
      QueryResult var14 = this.domainMgr.queryDomainsByCondition(var4);
      Object var5 = new ArrayList();
      if(var14.getLength() > 0) {
         var5 = var14.getData();
      }

      ArrayList var15 = new ArrayList();
      ArrayList var6 = new ArrayList();
      Iterator var7 = var1.iterator();

      Iterator var9;
      while(var7.hasNext()) {
         Long var8 = (Long)var7.next();
         var9 = ((List)var5).iterator();

         while(var9.hasNext()) {
            Domain var10 = (Domain)var9.next();
            if(var8.equals(var10.getId())) {
               var7.remove();
               break;
            }
         }
      }

      Iterator var20 = ((List)var5).iterator();

      while(var20.hasNext()) {
         Domain var22 = (Domain)var20.next();
         if(!var15.contains(var22.getPublicCloudId())) {
            var15.add(var22.getPublicCloudId());
         }
      }

      var20 = var15.iterator();

      HashMap var16;
      while(var20.hasNext()) {
         Long var23 = (Long)var20.next();

         try {
            ArrayList var24 = new ArrayList();
            var16 = new HashMap();
            var7 = ((List)var5).iterator();

            while(var7.hasNext()) {
               Domain var11;
               if((var11 = (Domain)var7.next()).getPublicCloudId() == var23) {
                  var24.add(var11.getUniqueKey());
                  var16.put(var11.getUniqueKey(), var11.getId());
               }
            }

            PublicCloud var18 = this.publicCloudMgr.queryPublicCloudById(var23);
            List var17 = FuncUtil.convertMapList2MdList(this.cloudResourceFactory.getCloudResource(var18).queryVmInfo(var16, var2, var3));
            var6.addAll(var17);
         } catch (AppException var12) {
            ServerUtils.logAppException(this.log, var12);
         } catch (Exception var13) {
            this.log.error((Object)null, var13);
         }
      }

      ArrayList var21 = new ArrayList();
      var9 = var1.iterator();

      while(var9.hasNext()) {
         Long var26 = (Long)var9.next();
         var16 = new HashMap();
         UserVm var19 = (UserVm)var2.get(var26);
         var16.put("id", var19.getDomainId());
         var16.put("name", "");
         var16.put("title", var19.getTitle());
         var16.put("status", "unknown");
         var16.put("cpuRate", Double.valueOf(0.0D));
         var16.put("memRate", Double.valueOf(0.0D));
         var16.put("cpu", Integer.valueOf(0));
         var16.put("mem", Long.valueOf(0L));
         var16.put("storage", Long.valueOf(0L));
         var16.put("flag", var19.getFlag());
         var21.add(var16);
      }

      List var25 = FuncUtil.convertMapList2MdList(var21);
      var6.addAll(var25);
      return var6;
   }

   public RpcPagingLoadResult queryTempletByOrgId(QueryConfig var1, LoginInfo var2) {
      return this.queryTempletByOrgId(var1, var2, Boolean.valueOf(false));
   }

   public RpcPagingLoadResult queryCloudOsTempletByOrgId(QueryConfig var1, LoginInfo var2) {
      Long var7 = (Long)var1.getRestriction("cloudId");
      var1.addRestriction("cloudId", var7);
      var1.addRestriction("cloudType", Integer.valueOf(5));
      var1.addRestriction("enable", Integer.valueOf(2));
      List var8 = this.domainMgr.queryDomainsByCondition(var1).getData();
      ArrayList var3 = new ArrayList();
      Iterator var9 = var8.iterator();

      while(var9.hasNext()) {
         Domain var4 = (Domain)var9.next();
         HashMap var5;
         (var5 = new HashMap()).put("id", var4.getId());
         var5.put("domainName", var4.getDomainName());
         var5.put("cpu", var4.getCpu());
         var5.put("memory", var4.getMemory());
         var5.put("system", var4.getSystem());
         Long var6 = var4.getStorageCapacity();
         var5.put("sysDisk", Long.valueOf(var6 == null?0L:var6.longValue() / 1024L));
         var5.put("createDate", var4.getCreateDate());
         var5.put("uuid", var4.getUniqueKey());
         var3.add(var5);
      }

      return new RpcPagingLoadResult(var3, (long)var1.getOffset(), (long)var3.size());
   }

   public List queryResourcePoolByOrgId(Long var1) {
      QueryResult var2;
      return (var2 = this.organizationMgr.queryResourcePoolByOrgId(var1)) != null && var2.getData() != null && var2.getData().size() > 0?var2.getData():null;
   }

   public List queryPublicCloudIdByOrgId(Long var1) {
      QueryConfig var2;
      (var2 = new QueryConfig()).addRestriction("orgId", var1);
      List var4 = this.organizationMgr.queryUserVmByOrgId(var2);
      ArrayList var6 = new ArrayList();
      Iterator var5 = var4.iterator();

      while(var5.hasNext()) {
         UserVm var3 = (UserVm)var5.next();
         if(!var6.contains(var3.getPublicCloudId())) {
            var6.add(var3.getPublicCloudId());
         }
      }

      return var6;
   }

   public List queryCloudIdsByOrgId(Long var1) {
      QueryConfig var2;
      (var2 = new QueryConfig()).addRestriction("orgId", var1);
      QueryResult var4 = this.organizationMgr.queryResourcePoolByConfig(var2);
      ArrayList var6 = new ArrayList();
      Iterator var5 = var4.getData().iterator();

      while(var5.hasNext()) {
         ResourcePool var3 = (ResourcePool)var5.next();
         if(!var6.contains(var3.getCloudId())) {
            var6.add(var3.getCloudId());
         }
      }

      return var6;
   }

   public QueryResult queryOrganizeByCondition(LoginInfo var1, QueryConfig var2) {
      ServerUtils.addOperatorGroupQueryCfg(var1, var2);
      ServerUtils.addOperatorQueryCfg(var1, var2);
      ArrayList var15 = new ArrayList();
      QueryResult var3;
      QueryResult var4;
      if((var3 = this.organizationMgr.queryOrganizationByConfig(var2)) != null && var3.getData() != null && var3.getData().size() > 0) {
         var2 = new QueryConfig();
         var4 = this.domainMgr.queryTemplateByConfig(var2);
         var2.addRestriction("flag", Integer.valueOf(1));
         QueryResult var16 = this.organizationMgr.queryOrgUserByCondition(var2);
         QueryResult var5 = this.organizationMgr.queryOrgUserVm();
         Iterator var6 = var3.getData().iterator();

         while(var6.hasNext()) {
            Organization var7 = (Organization)var6.next();
            int var8 = 0;
            int var9 = 0;
            int var10 = 0;
            int var11 = 0;
            OrganizePo var12 = new OrganizePo();
            Iterator var13;
            if(var5 != null && var5.getData() != null && var5.getData().size() != 0) {
               var13 = var5.getData().iterator();

               while(var13.hasNext()) {
                  Object[] var14;
                  if(FuncUtil.getLongValue((var14 = (Object[])var13.next())[1]).equals(var7.getId())) {
                     ++var9;
                     if(((String)var14[2]).equals("running")) {
                        ++var11;
                     }
                  }
               }
            }

            if(var4 != null && var4.getData() != null && var4.getData().size() > 0) {
               var13 = var4.getData().iterator();

               while(var13.hasNext()) {
                  if(FuncUtil.getLongValue(((Object[])var13.next())[1]).equals(var7.getId())) {
                     ++var8;
                  }
               }
            }

            if(var16 != null && var16.getData() != null) {
               var13 = var16.getData().iterator();

               while(var13.hasNext()) {
                  if(((OrgUser)var13.next()).getOrgId().longValue() == var7.getId().longValue()) {
                     ++var10;
                  }
               }
            }

            var12.setVmNum(Integer.valueOf(var9));
            var12.setTemplateNum(Integer.valueOf(var8));
            var12.setUserNum(Integer.valueOf(var10));
            var12.setId(var7.getId());
            var12.setName(var7.getName());
            var12.setRunVmNum(Integer.valueOf(var11));
            var15.add(var12);
         }
      }

      (var4 = new QueryResult()).setData(var15);
      if(var3 == null) {
         var4.setTotalLength(0L);
         var4.setOffset(0L);
      } else {
         var4.setTotalLength(var3.getTotalLength());
         var4.setOffset(var3.getOffset());
      }

      return var4;
   }

   public List queryResourcePoolByConfig(QueryConfig var1) {
      ArrayList var2 = new ArrayList();
      QueryResult var3;
      return (List)((var3 = this.organizationMgr.queryResourcePoolByConfig(var1)) != null && var3.getData() != null && var3.getData().size() > 0?var3.getData():var2);
   }

   public Organization queryOrgInfo(Long var1) {
      return this.organizationMgr.queryOrgById(var1);
   }

   public void addOrgAndOrgResourcePool(List var1, String var2, HttpSession var3, Organization var4) {
      if(this.organizationMgr.isOrgNameExist(var4.getName())) {
         throw new AppException(1501);
      } else if(var1 != null && var1.size() != 0) {
         ArrayList var7 = new ArrayList();
         Iterator var6 = var1.iterator();

         while(var6.hasNext()) {
            ResourcePoolPo var8 = (ResourcePoolPo)var6.next();
            if(this.resourcePoolMgr.queryRpById(var8.getId()) == null) {
               throw new AppException(17019, new Object[]{var8.getName()});
            }

            OrgResourcePool var5;
            (var5 = new OrgResourcePool()).setRpId(var8.getId());
            var7.add(var5);
         }

         this.organizationMgr.addOrgAndOrgResourcePool(var4, var7);
      } else {
         throw new AppException(17002);
      }
   }

   public void addOrgResourcePool(ResourcePoolPo var1) {
      if(this.resourcePoolMgr.queryRpById(var1.getId()) == null) {
         throw new AppException(17019, new Object[]{var1.getName()});
      } else {
         long var3 = var1.getOrgId().longValue();
         long var5 = var1.getId().longValue();
         if(this.organizationMgr.queryOrgResourcePoolById(var5, var3) != null) {
            throw new AppException(17020, new Object[]{var1.getName()});
         } else {
            OrgResourcePool var7;
            (var7 = new OrgResourcePool()).setRpId(Long.valueOf(var5));
            var7.setOrgId(Long.valueOf(var3));
            this.organizationMgr.addOrgResourcePool(var7);
         }
      }
   }

   public String checkResourcePoolExit(ResourcePoolPo var1) {
      String var2 = null;
      if(this.resourcePoolMgr.queryRpById(var1.getId()) != null) {
         var2 = var1.getName();
      }

      return var2;
   }

   public ResourcePool delOrgRp(Long var1, Long var2) {
      QueryConfig var3;
      (var3 = new QueryConfig()).addRestriction("orgId", var1);
      var3.addRestriction("rpId", var2);
      ResourcePool var4;
      if((var4 = this.organizationMgr.queryOrgResourcePoolByCf(var3)) != null) {
         this.organizationMgr.deleteOrgResourcePoolById(var1, var2);
      }

      return var4;
   }

   public void delOrgRp(HttpSession var1, Long var2, Long var3, String var4) {
      Organization var5 = this.organizationMgr.queryOrgById(var2);
      QueryConfig var6;
      (var6 = new QueryConfig()).addRestriction("orgId", var2);
      var6.addRestriction("resourcePoolId", var3);
      QueryResult var7;
      if((var7 = this.virDesktopPoolMgr.queryVirDesktopPoolList(var6)) != null && var7.getLength() != 0) {
         StringBuffer var8 = new StringBuffer();
         Iterator var9 = var7.getData().iterator();

         while(var9.hasNext()) {
            DesktopPool var10 = (DesktopPool)var9.next();
            var8.append(var10.getName() + ",");
         }

         var8.deleteCharAt(var8.length() - 1);
         this.operationLogMgr.addFailureLog(var1, 40, this.sm.getString("del.org.resourcepool.operation", new Object[]{var5.getName()}), this.sm.getString("org.resourcepool.not.exist"), var2);
         throw new AppException(17014, new Object[]{var4, var8});
      } else {
         var6.removeRestriction("resourcePoolId");
         var6.addRestriction("rpId", var3);
         if(this.organizationMgr.queryOrgResourcePoolByCf(var6) == null) {
            this.operationLogMgr.addFailureLog(var1, 40, this.sm.getString("del.org.resourcepool.operation", new Object[]{var5.getName()}), this.sm.getString("org.resourcepool.not.exist"), var2);
            throw new AppException(17002);
         }
      }
   }

   public RpcResult checkDelOrgRp(QueryConfig var1) {
      RpcResult var2 = new RpcResult();

      try {
         Long var3 = (Long)var1.getRestriction("orgId");
         Long var4 = (Long)var1.getRestriction("resourcePoolId");
         if(this.organizationMgr.queryOrgResourcePoolLength(var3).intValue() == 1) {
            throw new AppException(17011);
         } else if(this.virDesktopPoolMgr.countDesktopPoolsByResourcePoolId(var1) > 0) {
            ResourcePool var18 = this.resourcePoolMgr.queryResourcePoolById(var4);
            QueryResult var23 = this.virDesktopPoolMgr.queryVirDesktopPoolList(var1);
            StringBuilder var24 = new StringBuilder();
            if(var23 != null && var23.getData().size() > 0) {
               Iterator var15 = var23.getData().iterator();

               while(var15.hasNext()) {
                  DesktopPool var19 = (DesktopPool)var15.next();
                  var24.append(var19.getName()).append(",");
               }
            }

            if(var24.length() > 0) {
               var24.deleteCharAt(var24.length() - 1);
            }

            throw new AppException(17014, new Object[]{var18.getName(), var24.toString()});
         } else {
            QueryResult var16 = this.organizationMgr.queryUserVmByCondition(var1);
            QueryConfig var5;
            (var5 = new QueryConfig()).addRestriction("rpId", var1.getRestriction("resourcePoolId"));
            QueryResult var6 = this.resourcePoolMgr.queryClustersByCondition(var5);
            new StringBuilder();
            new StringBuilder();
            new ArrayList();
            new ArrayList();
            int var20 = 0;
            if(var6.getLength() > 0) {
               RpCluster var21 = (RpCluster)var6.getData().get(0);
               if(var16 != null && var16.getData() != null && var16.getData().size() > 0) {
                  Iterator var17 = var16.getData().iterator();

                  while(var17.hasNext()) {
                     UserVm var7 = (UserVm)var17.next();

                     try {
                        Domain var8;
                        if((var8 = this.domainMgr.queryDomainByIdNoException(var7.getDomainId())) != null && var8.getClusterId() == var21.getClusterId()) {
                           ++var20;
                           break;
                        }
                     } catch (Exception var10) {
                        this.log.error("domain not exist ");
                     }
                  }
               }

               if(var20 == 0 && (var16 = this.diskWorkflowMgr.queryByCondition(var1)) != null && var16.getLength() > 0) {
                  Iterator var25 = var16.getData().iterator();

                  while(var25.hasNext()) {
                     ApplyDisk var26 = (ApplyDisk)var25.next();

                     try {
                        Long var13;
                        Host var14;
                        if((var13 = var26.getHostId()) != null && (var14 = this.hostMgr.queryHostById(var13.longValue())) != null && var14.getClusterId() == var21.getClusterId()) {
                           ++var20;
                           break;
                        }
                     } catch (Exception var9) {
                        this.log.error("host not exist ");
                     }
                  }
               }
            }

            if(var20 > 0) {
               ResourcePool var22 = this.resourcePoolMgr.queryResourcePoolById(var4);
               var2.setSuccessMessage(this.sm.getString("org.resourcepool.used", new Object[]{var22.getName()}));
            }

            return var2;
         }
      } catch (AppException var11) {
         ServerUtils.logAppException(this.log, var11);
         return new RpcResult(var11.getErrorMessage(), var11.getErrorCode());
      } catch (Exception var12) {
         this.log.error("checkDelOrgRp error : ", var12);
         var2.setState(1);
         var2.setFailureMessage(var12.getMessage());
         return var2;
      }
   }

   public Integer queryOrgResourcePoolLength(Long var1) {
      return this.organizationMgr.queryOrgResourcePoolLength(var1);
   }

   public List queryUserVmListByDiskId(QueryConfig var1, long var2) {
      ArrayList var4 = new ArrayList();
      Long var5 = (Long)var1.getRestriction("userId");
      QueryResult var6;
      if((var6 = this.organizationMgr.queryOrgUserByUserId(var5)) != null && var6.getData() != null && var6.getData().size() > 0) {
         OrgUser var12 = (OrgUser)var6.getData().get(0);
         var1.addRestriction("orgId", var12.getOrgId());
         Long var13 = var12.getOrgId();
         Long var7 = (Long)var1.getRestriction("userGrpId");
         Host var8 = this.hostMgr.queryHostById(var2);
         List var9;
         if((var9 = this.organizationMgr.queryDomainListByDiskId(var5, var7, var13, var8.getClusterId())) != null && var9.size() != 0) {
            ArrayList var14 = new ArrayList();
            Iterator var10 = var9.iterator();

            while(var10.hasNext()) {
               Object[] var15 = (Object[])var10.next();
               var14.add((String)var15[0]);
            }

            PublicCloud var11 = PublicCloudUtils.getPublicCloudByHostId(Long.valueOf(var2), this.hostMgr, this.publicCloudMgr);
            List var16;
            if((var16 = this.queryVmByDiskId(var11, var14, var1)) != null && var16.size() != 0) {
               var4.addAll(var16);
            }
         }
      }

      return var4;
   }

   public List queryVmByDiskId(PublicCloud var1, List var2, QueryConfig var3) {
      return this.cloudResourceFactory.getCloudResource(var1).queryVmByDiskId(var2, var3);
   }

   public List queryTopCpuOrMemoryByConfig(Long var1, Long var2, String var3) {
      QueryConfig var4;
      (var4 = new QueryConfig()).addRestriction("orgId", var1);
      var4.addRestriction("rpId", var2);
      var4.addRestriction("type", var3);
      ArrayList var5 = new ArrayList();
      List var6;
      if((var6 = this.organizationMgr.queryTopCPUAndMemeryByconfig(var4)) != null && var6.size() != 0) {
         for(int var7 = 0; var7 < (var6.size() > 5?5:var6.size()); ++var7) {
            DomainPo var8;
            (var8 = new DomainPo()).setDomainName((String)((Object[])var6.get(var7))[2]);
            var8.setCpu(FuncUtil.getIntegerValue(((Object[])var6.get(var7))[0]));
            var8.setMemory(FuncUtil.getDoubleValue(((Object[])var6.get(var7))[1]));
            var5.add(var8);
         }
      }

      return var5;
   }

   public QueryResult queryDeskTop(Long var1, Long var2) {
      QueryConfig var3;
      (var3 = new QueryConfig()).addRestriction("orgId", var1);
      var3.addRestriction("resourcePoolId", var2);
      return this.virDesktopPoolMgr.queryVirDesktopPoolList(var3);
   }

   public void distriVmToUser(DistributeDomainData var1) {
      Long var2 = var1.getOrgId();
      Long var3 = var1.getVirDeskPoolId();
      Long var5 = var1.getDomainId();
      String var4 = var1.getName();
      String var6 = var1.getTitle();
      Integer var7 = var1.getCloudType();
      Long var8 = var1.getCloudId();
      if(StringUtils.isEmpty(var6)) {
         var6 = var4;
      }

      try {
         DomainUtils.checkVmLicense(var5, this.commonMgr);
         DomainUtils.orgAddVmApply(var2, var5, this.orgParamertersHandler, this.commonMgr, this.httpConnManager, this.domainMgr, this.publicCloudMgr);
         if(var3 != null) {
            String var9 = "SELECT COUNT( DISTINCT DOMAIN_ID) FROM TBL_USER_VM WHERE  DOMAIN_ID <> " + var5 + " AND DESKTOP_POOL_ID = " + var3;
            DesktopPool var10 = this.virDesktopPoolMgr.queryDesktopPoolById(var3);
            List var11 = this.organizationMgr.queryInfoBySql(var9);
            int var12 = 0;
            if(var11 != null && var11.size() > 0) {
               var12 = FuncUtil.getIntegerValue(var11.get(0)).intValue();
            }

            if(var12 >= var10.getMaxVmNum().intValue()) {
               Object[] var25 = new Object[]{Integer.valueOf(var10.getMaxVmNum().intValue())};
               throw new AppException(1525, var25);
            }
         }

         Long var24 = var8;
         if(var8 == null) {
            var24 = this.domainMgr.queryDomainById(var5).getPublicCloudId();
         }

         PublicCloud var26 = OrganizationUtils.getPublicCloudById(var24, this.publicCloudMgr);
         ResourcePool var27 = null;

         try {
            var27 = ResourcePoolUtils.getResourcePoolByDomainId(var5, this.resourcePoolMgr);
         } catch (Exception var15) {
            this.log.error(var15);
         }

         ArrayList var28 = new ArrayList();
         UserVm var13;
         List var18;
         if("user".equals(var1.getType())) {
            if((var18 = var1.getUserVmList()) != null) {
               Date var21 = var1.getExpireDate();

               UserVm var14;
               for(Iterator var19 = var18.iterator(); var19.hasNext(); var28.add(var14)) {
                  var13 = (UserVm)var19.next();
                  (var14 = new UserVm()).setOrgId(var2);
                  var14.setUserId(var13.getUserId());
                  if(var13.getUserGrpId() != null) {
                     var14.setUserGrpId(var13.getUserGrpId());
                  }

                  var14.setDomainId(var5);
                  var14.setTitle(var6);
                  var14.setFlag(Integer.valueOf(1));
                  var14.setPublicCloudId(var24);
                  var14.setDistributionDate(new Date());
                  if(var21 != null) {
                     var14.setExpireDate(var21);
                  }

                  if(var3 != null) {
                     var14.setDesktopPoolId(var3);
                  }

                  if(var1.getUniqueKey() != null) {
                     var14.setUniqueKey(var1.getUniqueKey());
                  }

                  if(var26.getFlag().intValue() == 5) {
                     var14.setDomainId(Long.valueOf(-1L));
                  }

                  if(var27 != null) {
                     var14.setResPoolId(var27.getId().longValue());
                  }
               }
            }
         } else if("userGrp".equals(var1.getType())) {
            if((var18 = var1.getUserVmList()) != null) {
               for(Iterator var22 = var18.iterator(); var22.hasNext(); var28.add(var13)) {
                  UserVm var20 = (UserVm)var22.next();
                  (var13 = new UserVm()).setOrgId(var2);
                  var13.setUserGrpId(var20.getUserGrpId());
                  var13.setDomainId(var5);
                  var13.setTitle(var6);
                  var13.setPublicCloudId(var24);
                  var13.setFlag(Integer.valueOf(2));
                  var13.setDistributionDate(new Date());
                  if(var1.getUniqueKey() != null) {
                     var13.setUniqueKey(var1.getUniqueKey());
                  }

                  if(var26.getFlag().intValue() == 5) {
                     var13.setDomainId(Long.valueOf(-1L));
                  }

                  if(var3 != null) {
                     var13.setDesktopPoolId(var3);
                  }

                  if(var27 != null) {
                     var13.setResPoolId(var27.getId().longValue());
                  }
               }
            }
         } else {
            UserVm var23;
            (var23 = new UserVm()).setOrgId(var2);
            var23.setDomainId(var5);
            var23.setTitle(var6);
            var23.setDistributionDate(new Date());
            var23.setPublicCloudId(var24);
            var23.setFlag(Integer.valueOf(0));
            if(var1.getUniqueKey() != null) {
               var23.setUniqueKey(var1.getUniqueKey());
            }

            if(var3 != null) {
               var23.setDesktopPoolId(var3);
            }

            if(var27 != null) {
               var23.setResPoolId(var27.getId().longValue());
            }

            var28.add(var23);
         }

         if(var28.size() > 0) {
            this.organizationMgr.addUserVmList(var28, var7);
         }

      } catch (AppException var16) {
         ServerUtils.logAppException(this.log, var16);
         throw var16;
      } catch (Exception var17) {
         this.log.error(var17);
         throw new AppException(11);
      }
   }

   public void checkDomainDistributed(Long var1, Long var2) {
      QueryConfig var3;
      (var3 = new QueryConfig()).addRestriction("domainId", var1);
      QueryResult var4;
      if(!CollectionUtils.isEmpty((var4 = this.organizationMgr.queryUserVmByCondition(var3)).getData())) {
         Iterator var5 = var4.getData().iterator();

         while(var5.hasNext()) {
            UserVm var6 = (UserVm)var5.next();
            if(!var2.equals(var6.getOrgId())) {
               throw new AppException(9165);
            }
         }
      }

   }

   public List queryDomainDistributedId(Long var1, Long var2, List var3, String var4) {
      QueryConfig var5;
      (var5 = new QueryConfig()).addRestriction("domainId", var1);
      var5.addRestriction("orgId", var2);
      QueryResult var8 = this.organizationMgr.queryUserVmByCondition(var5);
      ArrayList var10 = new ArrayList();
      if(!CollectionUtils.isEmpty(var8.getData())) {
         Iterator var9 = var8.getData().iterator();

         while(var9.hasNext()) {
            UserVm var11 = (UserVm)var9.next();
            Iterator var6 = var3.iterator();

            while(var6.hasNext()) {
               UserVm var7 = (UserVm)var6.next();
               if("user".equals(var4) && var7.getUserId().equals(var11.getUserId())) {
                  var10.add(var11.getUserId());
               }

               if("userGrp".equals(var4) && var7.getUserGrpId().equals(var11.getUserGrpId())) {
                  var10.add(var11.getUserGrpId());
               }
            }
         }
      }

      return var10;
   }

   public void SyncOrgTemp(RequestData var1) {
      Long var2 = (Long)var1.getData().get("orgId");
      Timer var3 = null;
      StringBuilder var4 = new StringBuilder();
      int var5 = 0;
      boolean var15 = false;

      label144: {
         label145: {
            try {
               String var20;
               try {
                  var15 = true;
                  List var6 = this.queryCloudIdsByOrgId(var2);
                  var3 = new Timer();
                  UpdateMessageTask var7 = new UpdateMessageTask(Long.valueOf(var1.getMessageId()), 3.3333333333333335D, var1.getOperateDesc(), this.messageMgr);
                  var3.schedule(var7, 0L, 1000L);
                  Iterator var21 = var6.iterator();

                  String var10;
                  while(var21.hasNext()) {
                     Long var8 = (Long)var21.next();
                     var10 = this.publicCloudMgr.queryPublicCloudById(var8).getName();

                     try {
                        this.publicCloudHandler.syncCloudTemp(var8.longValue());
                        ++var5;
                     } catch (Exception var16) {
                        var4.append(var10).append(",");
                     }
                  }

                  if(var4.length() > 0) {
                     var4.deleteCharAt(var4.length() - 1);
                  }

                  ArrayList var22 = new ArrayList();
                  BaseModelData var23;
                  (var23 = new BaseModelData()).set("value", var2);
                  var22.add(var23);
                  this.messageMgr.updateMessage(var1.getMessageId(), var22);
                  if(var5 == var6.size()) {
                     this.messageMgr.updateMessage(var1.getMessageId(), 100, this.sm.getString("org.sync.temp.successMsg", new Object[]{var1.getOperateTarget()}), true);
                     this.operationLogMgr.addSuccessLog(var1.getLoginName(), var1.getUserName(), var1.getIpAddress(), 3, var1.getOperateDesc(), var2, var2);
                     var15 = false;
                  } else {
                     String var9;
                     if(var5 > 0 && var5 < var6.size()) {
                        var9 = this.sm.getString("sync.resource.failed.msg", new Object[]{var4});
                        var10 = this.sm.getString("org.sync.temp.part.successMsg", new Object[]{var1.getOperateTarget()});
                        this.operationLogMgr.addLog(var1.getLoginName(), var1.getUserName(), var1.getIpAddress(), 3, OperationResult.PARTIAL_SUCCESS, var1.getOperateDesc(), var9, var2, var2);
                        this.messageMgr.updateMessage(var1.getMessageId(), 100, var10 + this.sm.getString("reason") + var9, Integer.valueOf(2));
                        var15 = false;
                     } else if(var5 == 0) {
                        var9 = this.sm.getString("sync.resource.failed.msg", new Object[]{var4});
                        var10 = this.sm.getString("org.sync.temp.failMsg", new Object[]{var1.getOperateTarget()});
                        this.operationLogMgr.addFailureLog(var1.getLoginName(), var1.getUserName(), var1.getIpAddress(), 3, var1.getOperateDesc(), var9, var2, var2);
                        this.messageMgr.updateMessage(var1.getMessageId(), 100, var10 + this.sm.getString("reason") + var9, false);
                        var15 = false;
                     } else {
                        var15 = false;
                     }
                  }
                  break label144;
               } catch (AppException var17) {
                  this.log.error((Object)null, var17);
                  var20 = this.sm.getString("org.sync.temp.failMsg", new Object[]{var1.getOperateTarget()});
                  this.operationLogMgr.addFailureLog(var1.getLoginName(), var1.getUserName(), var1.getIpAddress(), 201, var1.getOperateDesc(), var17.getErrorMessage(), var2, var2);
                  this.messageMgr.updateMessage(var1.getMessageId(), 100, var20 + this.sm.getString("reason") + var17.getErrorMessage(), false);
                  var15 = false;
               } catch (Exception var18) {
                  this.log.error((Object)null, var18);
                  var20 = this.sm.getString("org.sync.temp.failMsg", new Object[]{var1.getOperateTarget()});
                  this.operationLogMgr.addFailureLog(var1.getLoginName(), var1.getUserName(), var1.getIpAddress(), 201, var1.getOperateDesc(), ErrorCodes.getErrorMessage(11), var2, var2);
                  this.messageMgr.updateMessage(var1.getMessageId(), 100, var20 + this.sm.getString("reason") + ErrorCodes.getErrorMessage(11), false);
                  var15 = false;
                  break label145;
               }
            } finally {
               if(var15) {
                  if(var3 != null) {
                     var3.cancel();
                  }

               }
            }

            if(var3 != null) {
               var3.cancel();
               return;
            }

            return;
         }

         if(var3 != null) {
            var3.cancel();
            return;
         }

         return;
      }

      var3.cancel();
   }

   public void revokeDomain(VmUserPo var1, LoginInfo var2) {
      Long var3 = var1.getOrgId();
      String var4 = var1.getName();
      Integer var5 = var1.getFlag();
      String var6 = var1.getUniqueKey();
      Integer var7 = var1.getCloudType();
      Long var8 = var1.getDomainId();
      BaseModelData var9;
      (var9 = new BaseModelData()).set("orgId", var3);
      var9.set("domainId", var8);
      var9.set("title", var1.getTitle());
      var9.set("userName", var4);
      var9.set("flag", var5);
      var9.set("targetId", var1.getId());
      var9.set("desktopPoolId", var1.getDesktopPoolId());
      var9.set("cloudType", var7);
      var9.set("uniqueKey", var6);
      boolean var18 = this.organizationMgr.delUserVmByVmIdOrgId(var9);
      this.orgParamertersHandler.updateOrgParamers(var3);
      this.cloudBackUpStrategyMgr.deleteStrategyVm(var9);
      QueryConfig var15;
      (var15 = new QueryConfig()).addRestriction("domainId", var8);
      var15.addRestriction("targetId", var1.getId());
      var15.addRestriction("flag", var5);
      this.backupHistoryMgr.deleteVmBackupHistory(var15);
      Long var10;
      if(var18 && (var10 = (Long)var9.get("desktopPoolId")) != null) {
         DesktopPool var11;
         int var16 = (var11 = this.virDesktopPoolMgr.queryDesktopPoolById(var10)).getAssignMode().intValue();
         PublicCloud var12;
         if(2 == var16 && (var12 = ResourcePoolUtils.getPublicCloudByResourcePoolId(var11.getResourcePoolId(), this.resourcePoolMgr, this.publicCloudMgr)) != null) {
            String var17 = (String)var9.get("title");
            ModelData var19;
            if((var19 = (ModelData)this.domainHandler.queryDomainBasicInfoById(var12.getId(), var8).getData()) != null) {
               String var20 = (String)var19.get("status");
               if("running".equalsIgnoreCase(var20) || "paused".equalsIgnoreCase(var20)) {
                  BaseModelData var21;
                  (var21 = new BaseModelData()).set("id", var8);
                  var21.set("domainName", var19.get("title"));
                  var21.set("cloudId", var12.getId());
                  String var13 = this.strMng.getString("domainRestart.operation", new Object[]{var17});
                  RequestData var14 = new RequestData(33, var21, var2.getLoginName(), var2.getUserName(), var2.getLoginIp(), var13, var17, var8, var13);
                  this.requestMgr.postRequest(var14);
               }
            }
         }
      }

   }

   public List queryUserVmByVmId(Integer var1, Integer var2, Integer var3, String var4, Long var5, String var6, Integer var7, Long var8) {
      ArrayList var9 = new ArrayList();
      QueryConfig var11 = new QueryConfig(ServerUtils.convertSortDir(var3), var4, var1.intValue(), var2.intValue());
      if(var5 != null && var5.longValue() == -1L) {
         return new ArrayList();
      } else {
         if(var7 != null && var7.intValue() == 5) {
            var11.addRestriction("uniqueKey", var6);
         } else {
            var11.addRestriction("domainId", var5);
         }

         if(var8 != null) {
            var11.addRestriction("desktopPoolId", var8);
         }

         QueryResult var12;
         if((var12 = this.organizationMgr.queryUserVmByCondition(var11)) != null && var12.getData() != null && var12.getData().size() > 0) {
            Long var14 = ((UserVm)var12.getData().get(0)).getOrgId();
            Organization var17 = this.organizationMgr.queryOrgById(var14);
            HashMap var18 = new HashMap();
            QueryResult var19;
            Iterator var20;
            if((var19 = this.userMgr.queryUsersByOrgId(var14)) != null && var19.getData() != null) {
               var20 = var19.getData().iterator();

               while(var20.hasNext()) {
                  User var21 = (User)var20.next();
                  String var26 = "1-" + var21.getId();
                  var18.put(var26, var21);
               }
            }

            Iterator var23;
            if((var19 = this.userMgr.queryUserGroupByOrgId(var14)) != null && var19.getData() != null) {
               var23 = var19.getData().iterator();

               while(var23.hasNext()) {
                  UserGroup var27 = (UserGroup)var23.next();
                  String var22 = "2-" + var27.getId();
                  var18.put(var22, var27);
               }
            }

            StringBuilder var24 = new StringBuilder();
            HashMap var29 = new HashMap();
            var20 = var12.getData().iterator();

            UserVm var30;
            while(var20.hasNext()) {
               if((var30 = (UserVm)var20.next()).getDesktopPoolId() != null) {
                  var24.append(var30.getDesktopPoolId()).append(",");
               }
            }

            DesktopPool var10;
            if(var24.length() > 0) {
               var24.deleteCharAt(var24.length() - 1);
               QueryConfig var25;
               (var25 = new QueryConfig()).addRestriction("desktopPoolIdList", var24);
               QueryResult var31;
               if((var31 = this.virDesktopPoolMgr.queryVirDesktopPoolList(var25)) != null && var31.getData() != null && var31.getData().size() > 0) {
                  var23 = var31.getData().iterator();

                  while(var23.hasNext()) {
                     var10 = (DesktopPool)var23.next();
                     var29.put(var10.getId(), var10);
                  }
               }
            }

            BaseModelData var28;
            for(var20 = var12.getData().iterator(); var20.hasNext(); var9.add(var28)) {
               var30 = (UserVm)var20.next();
               var28 = new BaseModelData();
               if(var30.getFlag() != null) {
                  String var13;
                  Long var32;
                  if(var30.getFlag().intValue() == 1) {
                     var32 = var30.getUserId();
                     var28.set("id", var32);
                     var13 = "1-" + var32;
                     User var15;
                     if((var15 = (User)var18.get(var13)) != null) {
                        var28.set("name", var15.getLoginName());
                        var28.set("desc", var15.getUserName());
                     } else {
                        var28.set("name", "");
                        var28.set("desc", "");
                     }
                  } else if(var30.getFlag().intValue() == 2) {
                     var32 = var30.getUserGrpId();
                     var28.set("id", var32);
                     var13 = "2-" + var32;
                     UserGroup var16;
                     if((var16 = (UserGroup)var18.get(var13)) != null) {
                        var28.set("name", var16.getName());
                        var28.set("desc", var16.getDescription());
                     } else {
                        var28.set("name", "");
                        var28.set("desc", "");
                     }
                  }

                  var28.set("flag", var30.getFlag());
               } else {
                  var28.set("id", Long.valueOf(0L));
                  var28.set("name", "");
                  var28.set("desc", "");
                  var28.set("flag", Integer.valueOf(0));
               }

               var28.set("orgId", var14);
               if(var17 != null) {
                  var28.set("orgName", var17.getName());
               }

               if(var30.getDesktopPoolId() != null && var29.get(var30.getDesktopPoolId()) != null) {
                  var10 = (DesktopPool)var29.get(var30.getDesktopPoolId());
                  var28.set("desktopPoolId", var30.getDesktopPoolId());
                  var28.set("desktopPool", var10.getName());
                  var28.set("assignMode", var10.getAssignMode());
               }
            }

            var18.clear();
            var29.clear();
            return var9;
         } else {
            return new ArrayList();
         }
      }
   }

   public boolean checkDomainManagedByOrg(long var1, long var3) {
      return this.organizationMgr.checkDomainManagedByOrg(var1, var3);
   }
}
